@@ -35,9 +35,15 @@ FAILEDOPERATION_CREATERECORDFAILED = 'FailedOperation.CreateRecordFailed'
 # 私有域创建失败。
 FAILEDOPERATION_CREATEZONEFAILED = 'FailedOperation.CreateZoneFailed'
 
+# 数据异常。
+FAILEDOPERATION_DATAERROR = 'FailedOperation.DataError'
+
 # 当前私有域已关联 VPC，如需清空解析记录请先解除 VPC 关联。
 FAILEDOPERATION_DELETELASTBINDVPCRECORDFAILED = 'FailedOperation.DeleteLastBindVpcRecordFailed'
 
+# 记录删除失败。
+FAILEDOPERATION_DELETERECORDFAILED = 'FailedOperation.DeleteRecordFailed'
+
 # 解析域删除失败。
 FAILEDOPERATION_DELETEZONEFAILED = 'FailedOperation.DeleteZoneFailed'
 
